# Generated by Django 3.1 on 2020-10-08 11:19

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='MetaTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=50, unique=True)),
                ('title', models.CharField(max_length=50)),
                ('desc', models.CharField(max_length=100)),
                ('keywords', models.CharField(max_length=100)),
                ('author', models.CharField(max_length=50)),
                ('index', models.BooleanField(default=True)),
                ('follow', models.BooleanField(default=True)),
            ],
        ),
    ]
